==> parcel-bundler-vue-1.6.3.tgz: package/lib/packagers/RawPackager.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Packager = require('./Packager');
var fs = require('../utils/fs');
var path = require('path');
var url = require('url');

var RawPackager = function (_Packager) {
  (0, _inherits3.default)(RawPackager, _Packager);

  function RawPackager() {
    (0, _classCallCheck3.default)(this, RawPackager);
    return (0, _possibleConstructorReturn3.default)(this, (RawPackager.__proto__ || (0, _getPrototypeOf2.default)(RawPackager)).apply(this, arguments));
  }

  (0, _createClass3.default)(RawPackager, [{
    key: 'setup',

    // Override so we don't create a file for this bundle.
    // Each asset will be emitted as a separate file instead.
    value: function setup() {}
  }, {
    key: 'addAsset',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(asset) {
        var name, contents;
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                // Use the bundle name if this is the entry asset, otherwise generate one.
                name = this.bundle.name;

                if (asset !== this.bundle.entryAsset) {
                  name = url.resolve(path.join(path.dirname(this.bundle.name), asset.generateBundleName()), '');
                }

                contents = asset.generated[asset.type];

                if (!(!contents || contents && contents.path)) {
                  _context.next = 7;
                  break;
                }

                _context.next = 6;
                return fs.readFile(contents ? contents.path : asset.name);

              case 6:
                contents = _context.sent;

              case 7:

                this.size = contents.length;
                _context.next = 10;
                return fs.writeFile(name, contents);

              case 10:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function addAsset(_x) {
        return _ref.apply(this, arguments);
      }

      return addAsset;
    }()
  }, {
    key: 'getSize',
    value: function getSize() {
      return this.size || 0;
    }
  }, {
    key: 'end',
    value: function end() {}
  }]);
  return RawPackager;
}(Packager);

module.exports = RawPackager;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/packagers/RawPackager.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Packager = require('./Packager');
var fs = require('../utils/fs');
var path = require('path');
var url = require('url');

var RawPackager = function (_Packager) {
  (0, _inherits3.default)(RawPackager, _Packager);

  function RawPackager() {
    (0, _classCallCheck3.default)(this, RawPackager);
    return (0, _possibleConstructorReturn3.default)(this, (RawPackager.__proto__ || (0, _getPrototypeOf2.default)(RawPackager)).apply(this, arguments));
  }

  (0, _createClass3.default)(RawPackager, [{
    key: 'setup',

    // Override so we don't create a file for this bundle.
    // Each asset will be emitted as a separate file instead.
    value: function setup() {}
  }, {
    key: 'addAsset',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(asset) {
        var name, contents;
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                // Use the bundle name if this is the entry asset, otherwise generate one.
                name = this.bundle.name;

                if (asset !== this.bundle.entryAsset) {
                  name = url.resolve(path.join(path.dirname(this.bundle.name), asset.generateBundleName()), '');
                }

                _context.t0 = asset.generated[asset.type];

                if (_context.t0) {
                  _context.next = 7;
                  break;
                }

                _context.next = 6;
                return fs.readFile(asset.name);

              case 6:
                _context.t0 = _context.sent;

              case 7:
                contents = _context.t0;
                _context.next = 10;
                return fs.writeFile(name, contents);

              case 10:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function addAsset(_x) {
        return _ref.apply(this, arguments);
      }

      return addAsset;
    }()
  }, {
    key: 'end',
    value: function end() {}
  }]);
  return RawPackager;
}(Packager);

module.exports = RawPackager;
